==> haskell-graphite-0.10.0.1-298-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-5Sy05eydSVEFNUxzFkrdL8
key:                  graphite-0.10.0.1-5Sy05eydSVEFNUxzFkrdL8
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  4a5e4a142596f4d824a9d9e9ce253584
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-5Sy05eydSVEFNUxzFkrdL8
depends:
    QuickCheck-2.14.3-76HC5XzyauqDQFZ8BHcZeC base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.0-KrNcUwKkbvA9oliPW1AyZZ
    containers-0.6.7 deepseq-1.4.8.0
    graphviz-2999.20.2.1-CdKUCODIixLia0yqBten3
    hashable-1.4.4.0-1zcla4qwUGf6ADT5z5m7Nb process-1.6.18.0
    random-1.2.1.3-G8HhURP50mfDOIe4gICdYG text-2.0.2
    unordered-containers-0.2.20-5ChD9TF8iAH5uLARI0QLMz
    vector-0.13.2.0-GjxrA8HCtQq4MGRlxeWifh

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-graphite-0.10.0.1-299-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-graphite.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 graphite
version:              0.10.0.1
visibility:           public
id:                   graphite-0.10.0.1-79l5cnwTnhk11PIytCxkJi
key:                  graphite-0.10.0.1-79l5cnwTnhk11PIytCxkJi
license:              BSD-3-Clause
copyright:            2017 Daniel Campoverde
maintainer:           alx@sillybytes.net
author:               Daniel Campoverde
homepage:             https://github.com/alx741/graphite#readme
synopsis:             Graphs and networks library
description:          Represent, analyze and visualize graphs
category:             Data Structures, Graphs
abi:                  7946eb1b819be6f8845c2c5ed979c3a8
exposed:              True
exposed-modules:
    Data.Graph.Connectivity Data.Graph.DGraph
    Data.Graph.DGraph.DegreeSequence Data.Graph.Generation
    Data.Graph.Morphisms Data.Graph.Read Data.Graph.Traversal
    Data.Graph.Types Data.Graph.UGraph Data.Graph.UGraph.DegreeSequence
    Data.Graph.Visualize

hidden-modules:       Data.Graph.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/graphite-0.10.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-graphite
hs-libraries:         HSgraphite-0.10.0.1-79l5cnwTnhk11PIytCxkJi
depends:
    QuickCheck-2.14.3-6LKdi6bmSSC7fWzYy22Dkb base-4.17.2.1
    bytestring-0.11.5.3 cassava-0.5.4.0-8Q8oNf0FvCnFcuqWu3ckqC
    containers-0.6.7 deepseq-1.4.8.0
    graphviz-2999.20.2.1-BwJkdfLfMOFD5YRUyEI8dq
    hashable-1.4.4.0-9uPnQxUdwOnCZlD9EiHqMs process-1.6.18.0
    random-1.2.1.3-FtBkzNFMEVVAWMk0jeYogw text-2.0.2
    unordered-containers-0.2.20-3iRUctzIz2JCUYhLp7SKku
    vector-0.13.2.0-GniUvXn58d91eC1W7jmZ0

haddock-interfaces:   /usr/share/doc/haskell-graphite/html/graphite.haddock
haddock-html:         /usr/share/doc/haskell-graphite/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
